componenttools.split_components_at_offsets
==========================================

.. autofunction:: abjad.tools.componenttools.split_components_at_offsets.split_components_at_offsets
   :noindex:
